# trezor-common

[![Build Status](https://travis-ci.org/trezor/trezor-common.svg?branch=master)](https://travis-ci.org/trezor/trezor-common)
[![Gitter](https://badges.gitter.im/trezor/community.svg)](https://gitter.im/trezor/community)

Common files shared among TREZOR repositories.

This repo is meant to be included as submodule to others using:

```
git submodule add https://github.com/trezor/trezor-common.git trezor-common
```
